@@ -633,7 +633,7 @@ class MockBroker(BaseBroker):
             return df
 
         # 정규장 정보로만 거르기 ==================================
-        market_schedule = get_market_schedule(today, "NYSE" if self.market == "us_stock" else "KRX")
+        market_schedule = get_market_schedule(today, self._get_exchange_code())
         open_time = dtm.datetime.combine(today, market_schedule.open_time)
         close_time = dtm.datetime.combine(today, market_schedule.close_time)
 
@@ -732,7 +732,9 @@ class MockBroker(BaseBroker):
                 dfs_nxt = get_kr_minute_data(date, [code], dtm.timedelta(minutes=1), source="kis", adjusted=True, exchange=DataExchange.NXT)
                 if code in dfs_nxt and not dfs_nxt[code].empty:
                     _df = dfs[code]
+                    _df = _df[(_df.cum_volume > 0)]  # 머지 시 9:00, 9:01 데이터가 문제가 있는 경우를 위해 발라냄
                     _df_nxt = dfs_nxt[code]
+                    _df_nxt = _df_nxt[(_df_nxt.cum_volume > 0)]
                     common_dates = _df.index.intersection(_df_nxt.index)
                     for _date in common_dates:
                         _df_nxt.loc[_date, 'volume'] = _df.loc[_date, 'volume'] + _df_nxt.loc[_date, 'volume']
@@ -1016,7 +1018,7 @@ class MockBroker(BaseBroker):
         nxt_pre_close_time = nxt_pre_open_time + dtm.timedelta(minutes=50)
         # nxt_main_open_time = dtm.datetime.combine(today, open_time) + dtm.timedelta(seconds=30)
         # nxt_main_close_time = close_time - dtm.timedelta(minutes=10)
-        nxt_after_open_time = close_time
+        nxt_after_open_time = close_time + dtm.timedelta(minutes=10)
         nxt_after_close_time = dtm.datetime.combine(today, nxt_market_schedule.close_time)
 
         just_closed = current_time.replace(second=0, microsecond=0) == close_time.replace(second=0, microsecond=0)
@@ -1027,7 +1029,13 @@ class MockBroker(BaseBroker):
         if market_schedule.full_day_closed or current_time < open_time or (current_time > close_time and not just_closed):
             if self.market_nxt_on and not market_schedule.full_day_closed:
                 # market_nxt_on 인 경우 메인 마켓은 KRX 그대로 사용하고 프리마켓과 애프터마켓만 추가한다.
-                if current_time < nxt_pre_open_time or nxt_pre_close_time <= current_time < open_time or close_time < current_time < nxt_after_open_time or nxt_after_close_time <= current_time:
+                is_in_nxt_pre_market = (
+                    nxt_pre_open_time < open_time
+                    and nxt_pre_open_time <= current_time < nxt_pre_close_time
+                )
+                is_in_main_market = open_time <= current_time < close_time
+                is_in_nxt_after_market = nxt_after_open_time <= current_time < nxt_after_close_time
+                if not is_in_nxt_pre_market and not is_in_main_market and not is_in_nxt_after_market:
                     self.logger.warning(f"on_time_change(nxt_on): {before_time} ~ {current_time} market is closed")
                     return
             else:
