@@ -499,7 +499,7 @@ class KISSimpleDomesticStock:
                     }
                 )
 
-        df = pd.DataFrame(result)
+        df = pd.DataFrame(result, columns=["code", "current_price", "volume", "open_price", "high_price", "low_price", "diff", "diff_rate"])
         df.set_index("code", inplace=True)
         return df
 
@@ -804,7 +804,8 @@ class KISSimpleDomesticStock:
             price_df = self.get_price_for_multiple_stock(list(asset_codes))
 
         for order in result:
-            order.current_price = int(price_df.loc[order.asset_code, "current_price"])
+            if order.asset_code in price_df.index:
+                order.current_price = int(price_df.loc[order.asset_code, "current_price"])
 
         if not self._is_all_exchanges(exchanges):
             result = [order for order in result if order.exchange in exchanges]
@@ -868,7 +869,8 @@ class KISSimpleDomesticStock:
             price_df = self.get_price_for_multiple_stock(asset_codes)
 
         for order in result:
-            order.current_price = int(price_df.loc[order.asset_code, "current_price"])
+            if order.asset_code in price_df.index:
+                order.current_price = int(price_df.loc[order.asset_code, "current_price"])
 
         return result
 
