@@ -118,7 +118,7 @@ class TradingTrackerMultiProcessWorker:
                     hts_id=os.getenv("KIS_HTS_ID"),
                 )
         self.tracker = TradingTracker(self.simple_api, fee_rate=fee_rate)
-        self.tracker.on_pending_order_update = self.on_pending_order_update
+        self.tracker.add_pending_order_update_callback(self.on_pending_order_update)
 
     async def start(self):
         """
