@@ -229,7 +229,8 @@ def _isoformat_to_readable(isodate: str) -> str:
     return ""
 
 
-@domesticCache.memoize()
+# _get_tickers가 메모이제이션 되어있어서 해당 함수는 캐싱하면 안됨
+# 특히 date가 None으로 쓰는경우가 많은데 캐싱하면 오작동함
 def get_tickers(
     date: Optional[dtm.date] = None,
     market: Optional[str] = None,
