@@ -1,6 +1,6 @@
 import datetime
 from decimal import ROUND_CEILING, ROUND_FLOOR, ROUND_HALF_UP, Decimal
-from typing import Union
+from typing import Union, Optional
 
 
 def quantize_krx_price(price: Union[Decimal, int, float], etf_etn: bool, rounding: str = "floor") -> int:
@@ -50,7 +50,7 @@ def get_krx_tick_size(
     price: float,
     etf_etn: bool,
     market: str = "KOSPI",
-    date: datetime.date = None,
+    date: Optional[datetime.date] = None,
 ) -> int:
     """
     주어진 가격과 금융 상품 유형에 따라 적절한 호가가격단위를 반환합니다.
