@@ -1,30 +1,59 @@
 import logging
-from logging.handlers import TimedRotatingFileHandler
-import pyqqq.config as c
+import logging.handlers
 import sys
+from logging.handlers import TimedRotatingFileHandler
 
-_format = "%(levelname).1s %(name)s: %(message)s"
+import pyqqq.config as c
+from pyqqq.backtest.wallclock import WallClock
 
+_default_format = "%(levelname).1s %(name)s: %(message)s"
 if not c.is_google_cloud_logging_enabled():
-    _format = "%(asctime)s " + _format
+    _default_format = "%(asctime)s " + _default_format
 
-_stdout_h = logging.StreamHandler(sys.stdout)
+
+class CustomHandler(logging.StreamHandler):
+    custom_format: str
+
+    class ClockFormatter(logging.Formatter):
+        def __init__(self, fmt=None, style="%", clock: WallClock = None):
+            super().__init__(fmt, style)
+            self.clock = clock or WallClock(live_mode=True)
+
+        def formatTime(self, record, datefmt=None):
+            dt = self.clock.now()
+            return dt.isoformat(timespec="milliseconds")
+
+    def __init__(self, stream):
+        super().__init__(stream)
+        self.custom_format = _default_format
+        self.setFormatter(logging.Formatter(self.custom_format))
+
+    def emit(self, record):
+        super().emit(record)
+
+    def update_format(self, format=None, clock: WallClock = None):
+        if format:
+            self.custom_format = format
+        self.setFormatter(self.ClockFormatter(self.custom_format, clock=clock))
+
+
+_stdout_h = CustomHandler(sys.stdout)
 _stdout_h.setLevel(logging.DEBUG)
 _stdout_h.addFilter(lambda r: r.levelno <= logging.WARNING)
 
-_stderr_h = logging.StreamHandler(sys.stderr)
+_stderr_h = CustomHandler(sys.stderr)
 _stderr_h.setLevel(logging.ERROR)
 
-logging.basicConfig(format=_format, handlers=[_stdout_h, _stderr_h])
+logging.basicConfig(handlers=[_stdout_h, _stderr_h])
 
 
 def get_logger(
-        name,
-        level=logging.DEBUG,
-        filename: str = None,
-        when: str = 'h',
-        interval: int = 1,
-        backup_count: int = 24,
+    name,
+    level=logging.DEBUG,
+    filename: str = None,
+    when: str = "h",
+    interval: int = 1,
+    backup_count: int = 24,
 ) -> logging.Logger:
     """
     로깅을 위한 Logger 객체를 구성하고 반환합니다.
@@ -52,19 +81,17 @@ def get_logger(
     logger.setLevel(level)
 
     if not logger.handlers and filename:
-        fh = TimedRotatingFileHandler(
-            filename, when=when, backupCount=backup_count, interval=interval
-        )
+        fh = TimedRotatingFileHandler(filename, when=when, backupCount=backup_count, interval=interval)
         fh.setLevel(level)
-        fh.setFormatter(logging.Formatter(_format))
+        fh.setFormatter(logging.Formatter(_default_format))
         logger.addHandler(fh)
 
     return logger
 
 
 def get_bare_logger(
-        name,
-        level=logging.NOTSET,
+    name,
+    level=logging.NOTSET,
 ) -> logging.Logger:
     """
     level을 지정하지 않으면 NOTSET으로 설정되는 로거를 반환하기 위해 사용됩니다.
@@ -113,3 +140,10 @@ def set_module_logger_level(level, name="pyqqq"):
     for logger_name in logging.root.manager.loggerDict:
         if logger_name == name or logger_name.startswith(f"{name}."):
             logging.getLogger(logger_name).setLevel(level)
+
+
+def get_handlers():
+    """
+    CustomHandler 클래스의 인스턴스를 반환합니다.
+    """
+    return [h for h in logging.root.handlers if isinstance(h, CustomHandler)]
